@@ -43,6 +43,7 @@ from datalad.tests.utils import (
     assert_result_count,
     assert_status,
     create_tree,
+    DEFAULT_BRANCH,
     eq_,
     known_failure_windows,
     neq_,
@@ -51,6 +52,7 @@ from datalad.tests.utils import (
     serve_path_via_http,
     skip_if_on_windows,
     skip_ssh,
+    slow,
     swallow_logs,
     with_tempfile,
     with_testrepos,
@@ -102,7 +104,7 @@ def test_smth_about_not_supported(p1, p2):
     source = Dataset(p1).create()
     from datalad.support.network import PathRI
     source.create_sibling(
-        'ssh://localhost' + PathRI(p2).posixpath,
+        'ssh://datalad-test' + PathRI(p2).posixpath,
         name='target1')
     # source.publish(to='target1')
     with chpwd(p1):
@@ -172,8 +174,8 @@ def test_publish_simple(origin, src_path, dst_path):
 
     assert_repo_status(source.repo, annex=None)
     assert_repo_status(target, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # don't fail when doing it again
     res = publish(dataset=source, to="target")
@@ -182,11 +184,11 @@ def test_publish_simple(origin, src_path, dst_path):
 
     assert_repo_status(source.repo, annex=None)
     assert_repo_status(target, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(source.repo, target)
 
-    # 'target/master' should be tracking branch at this point, so
+    # 'target/<default branch>' should be tracking branch at this point, so
     # try publishing without `to`:
     # MIH: Nope, we don't automatically add this anymore
 
@@ -201,8 +203,8 @@ def test_publish_simple(origin, src_path, dst_path):
     eq_(res, [source])
 
     assert_repo_status(dst_path, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(source.repo, target)
 
     eq_(filter_fsck_error_msg(source.repo.fsck()),
@@ -231,8 +233,8 @@ def test_publish_plain_git(origin, src_path, dst_path):
 
     assert_repo_status(source.repo, annex=None)
     assert_repo_status(target, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # don't fail when doing it again
     res = publish(dataset=source, to="target")
@@ -241,8 +243,8 @@ def test_publish_plain_git(origin, src_path, dst_path):
 
     assert_repo_status(source.repo, annex=None)
     assert_repo_status(target, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # some modification:
     with open(opj(src_path, 'test_mod_file'), "w") as f:
@@ -255,8 +257,8 @@ def test_publish_plain_git(origin, src_path, dst_path):
     eq_(res, [source])
 
     assert_repo_status(dst_path, annex=None)
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # amend and change commit msg in order to test for force push:
     source.repo.commit("amended", options=['--amend'])
@@ -268,6 +270,7 @@ def test_publish_plain_git(origin, src_path, dst_path):
     eq_(res, [source])
 
 
+@slow  # 12sec on travis
 # https://github.com/datalad/datalad/pull/3975/checks?check_run_id=369789022#step:8:380
 @known_failure_windows
 @with_testrepos('submodule_annex', flavors=['local'])
@@ -332,14 +335,14 @@ def test_publish_recursive(pristine_origin, origin_path, src_path, dst_path, sub
     eq_({r['path'] for r in res},
         {src_path, sub1.path, sub2.path})
 
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(source.repo, target)
-    eq_(list(sub1_target.get_branch_commits_("master")),
-        list(sub1.get_branch_commits_("master")))
+    eq_(list(sub1_target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(sub1.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(sub1, sub1_target)
-    eq_(list(sub2_target.get_branch_commits_("master")),
-        list(sub2.get_branch_commits_("master")))
+    eq_(list(sub2_target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(sub2.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(sub2, sub2_target)
 
     # we are tracking origin but origin has different git-annex, since we
@@ -422,7 +425,8 @@ def test_publish_recursive(pristine_origin, origin_path, src_path, dst_path, sub
     # merge point"
     source.save(message="Changes in subm2")
     # and test if it could deduce the remote/branch to push to
-    source.config.set('branch.master.remote', 'target', where='local')
+    source.config.set('branch.{}.remote'.format(DEFAULT_BRANCH),
+                      'target', where='local')
     with chpwd(source.path):
         res_ = publish(since='', recursive=True)
     # TODO: somehow test that there were no even attempt to diff within "subm 1"
@@ -436,6 +440,7 @@ def test_publish_recursive(pristine_origin, origin_path, src_path, dst_path, sub
 
 
 # https://github.com/datalad/datalad/pull/3975/checks?check_run_id=369789022#step:8:452
+@slow  # 10sec on Yarik's laptop
 @known_failure_windows
 @with_testrepos('submodule_annex', flavors=['local'])  #TODO: Use all repos after fixing them
 @with_tempfile(mkdir=True)
@@ -473,12 +478,12 @@ def test_publish_with_data(origin, src_path, dst_path, sub1_pub, sub2_pub, dst_c
     eq_(set(res), set([opj(source.path, 'test-annex.dat'), source.path]))
     # XXX master was not checked out in dst!
 
-    eq_(list(target.get_branch_commits_("master")),
-        list(source.repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(source.repo.get_branch_commits_(DEFAULT_BRANCH)))
     assert_git_annex_branch_published(source.repo, target)
 
-    # we need compare target/master:
-    target.checkout("master")
+    # we need compare target/<default branch>:
+    target.checkout(DEFAULT_BRANCH)
     ok_(target.file_has_content('test-annex.dat'))
 
     # make sure that whatever we published is actually consumable
@@ -527,6 +532,7 @@ def test_publish_with_data(origin, src_path, dst_path, sub1_pub, sub2_pub, dst_c
         filter_fsck_error_msg(source.repo.fsck(remote='target')))
 
 
+@slow  # 10sec on travis
 @skip_if_on_windows  # create_sibling incompatible with win servers
 @skip_ssh
 @with_testrepos('submodule_annex', flavors=['local'])
@@ -550,7 +556,7 @@ def test_publish_depends(
 
     # two remote sibling on two "different" hosts
     source.create_sibling(
-        'ssh://localhost' + target1_path,
+        'ssh://datalad-test' + target1_path,
         annex_wanted='standard',
         annex_group='backup',
         name='target1')
@@ -657,7 +663,7 @@ def test_publish_gh1691(origin, src_path, dst_path):
 
     # create the target(s):
     source.create_sibling(
-        'ssh://localhost:' + dst_path,
+        'ssh://datalad-test:' + dst_path,
         name='target', recursive=True)
 
     # publish recursively, which silently ignores non-installed datasets
@@ -679,7 +685,7 @@ def test_publish_target_url(src, desttop, desturl):
     # https://github.com/datalad/datalad/issues/1762
     ds = Dataset(src).create(force=True)
     ds.save('1')
-    ds.create_sibling('ssh://localhost:%s/subdir' % desttop,
+    ds.create_sibling('ssh://datalad-test:%s/subdir' % desttop,
                       name='target',
                       target_url=desturl + 'subdir/.git')
     results = ds.publish(to='target', transfer_data='all')
@@ -687,6 +693,7 @@ def test_publish_target_url(src, desttop, desturl):
     ok_file_has_content(_path_(desttop, 'subdir/1'), '123')
 
 
+@slow  # 11sec on Yarik's laptop
 @skip_if_on_windows  # create_sibling incompatible with win servers
 @skip_ssh
 @with_tempfile(mkdir=True)
@@ -750,6 +757,7 @@ def test_publish_no_fetch_refspec_configured(path):
     ds.publish(to="origin")
 
 
+@slow  # 14sec on Yarik's laptop
 @skip_ssh
 @with_tempfile(mkdir=True)
 def test_publish_fetch_do_not_recurse_submodules(path):
